tsseg.algorithms.fluss package
==============================

Matrix-profile-based: derives Arc Curve and detects boundaries at valleys.

| **Type:** change point detection
| **Supervision:** semi-supervised or unsupervised
| **Requires:** ``stumpy``

**Implementation:** Wrapper around stumpy. BSD 3-Clause.

**Reference:** Gharghabi et al. (2017), ICDM.

Submodules
----------

tsseg.algorithms.fluss.detector module
--------------------------------------

.. automodule:: tsseg.algorithms.fluss.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.fluss
   :members:
   :show-inheritance:
   :undoc-members:
